#include <windows.h>

enum
{
	BATTERY_OK,
	BATTERY_LOW,
	BATTERY_CRITICAL
};

void CALLBACK CheckBatteryStatus (HWND, UINT, UINT, DWORD)
{
	static int prev_status = BATTERY_OK;

	SYSTEM_POWER_STATUS sps;
	if (GetSystemPowerStatus (&sps))
	{
		//Is the battery charging?
		if (sps.BatteryFlag & BATTERY_FLAG_CHARGING)
		{
			//Mark as OK
			prev_status = BATTERY_OK;
		} else {
			/*
				Check the status (critical is 5%, low is 10%)
				Values in sps.BatteryFlag aren't useful:
				- BATTERY_FLAG_LOW (25%)
				- BATTERY_FLAG_CRITICAL (5%)
			*/
			int new_status = BATTERY_OK;
			if (sps.BatteryLifePercent <= 5) new_status = BATTERY_CRITICAL;
			else if (sps.BatteryLifePercent <= 10) new_status = BATTERY_LOW;

			//If there was a status change
			if (new_status != prev_status)
			{
				//Display a message
				switch (prev_status = new_status)
				{
				case BATTERY_LOW :
					MessageBox (NULL, "Battery power level is low.", "Notification", MB_ICONINFORMATION);
					break;
				case BATTERY_CRITICAL :
					MessageBox (NULL, "Battery power level is critical!", "Notification", MB_ICONEXCLAMATION);
					break;
				}
			}
		}
	}
}

int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR szCmdLine, int iCmdShow)
{
	SetTimer (NULL, 0, 60000, CheckBatteryStatus);

	MSG msg;
	while (GetMessage (&msg, NULL, 0, 0))
	{
		TranslateMessage (&msg);
		DispatchMessage (&msg);
	}

	return 0;
}